========================
django-codenerix-reviews
========================

Codenerix Reviews is a module that enables `CODENERIX <https://www.codenerix.com/>`_ to add reviews to articles publishe with django-codenerix-cms.

.. image:: https://github.com/codenerix/django-codenerix/raw/master/codenerix/static/codenerix/img/codenerix.png
    :target: https://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

****
Demo
****

Coming soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-reviews
    For python 3: sudo pip3 install django-codenerix-reviews

2. Add "codenerix_reviews" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_reviews',
    ]

3. Add in settings the params::

    # path for codenerix_reviews
    CDNX_REVIEWS = 'reviews'

4. Since Codenerix Reviews is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us?

You can get in touch with us `here <https://codenerix.com/contact/>`_.
